@@ -145,7 +145,12 @@ class Release:
 
         if not version:
             current = self._get_current_versions(countries)
-            releases = self._get_releases_since(max(rel["version"] for rel in current))
+            if current:
+                releases = self._get_releases_since(
+                    max(rel["version"] for rel in current)
+                )
+            else:
+                releases = self._get_releases_since("0.1.0")  # default
             if not releases:
                 logger.error(f"No new release found for project {self._project}!")
                 sys.exit(-1)
@@ -238,22 +243,16 @@ class Release:
     def _get_releases_since(self, threshold):
         releases = self._repo.get_releases()
 
-        if threshold:
-            return [
-                rel for rel in releases if semver.compare(threshold, rel.tag_name) == -1
-            ]
-
-        return releases.sort(reverse=True)[0:4]
+        return [
+            rel for rel in releases if semver.compare(threshold, rel.tag_name) == -1
+        ][0:4]
 
     def _get_releases_before(self, threshold):
         releases = self._repo.get_releases()
 
-        if threshold:
-            return [
-                rel for rel in releases if semver.compare(threshold, rel.tag_name) == 1
-            ]
-
-        return releases.sort(reverse=True)[0:4]
+        return [
+            rel for rel in releases if semver.compare(threshold, rel.tag_name) == 1
+        ][0:4]
 
     def _manage_youtrack_card(self, commits, new_version, countries):
         release_state = self._config.youtrack["release_state"]
